@@ -1,9 +1,5 @@
-# coding: utf-8
-from __future__ import absolute_import, unicode_literals
-
 from django.db import models
-
-from django_tables2.templatetags.django_tables2 import title
+from django.utils.text import capfirst
 
 from .base import library
 from .linkcolumn import BaseLinkColumn
@@ -11,14 +7,14 @@ from .linkcolumn import BaseLinkColumn
 
 @library.register
 class EmailColumn(BaseLinkColumn):
-    '''
-    Render email addresses to mailto-links.
+    """
+    Render email addresses to `mailto:`-links.
 
     Arguments:
         attrs (dict): HTML attributes that are added to the rendered
-            ``<a href="...">...</a>`` tag
+                      ``<a href="...">...</a>`` tag.
         text: Either static text, or a callable. If set, this will be used to
-            render the text inside link instead of the value
+              render the text inside link instead of the value.
 
     Example::
 
@@ -34,15 +30,12 @@ class EmailColumn(BaseLinkColumn):
 
         # result
         # [...]<a href="mailto:email@example.com">email@example.com</a>
-    '''
-    def render(self, record, value):
-        return self.render_link(
-            uri='mailto:{}'.format(value),
-            record=record,
-            value=value
-        )
+    """
+
+    def get_url(self, value):
+        return "mailto:{}".format(value)
 
     @classmethod
     def from_field(cls, field):
         if isinstance(field, models.EmailField):
-            return cls(verbose_name=title(field.verbose_name))
+            return cls(verbose_name=capfirst(field.verbose_name))
