@@ -1,9 +1,5 @@
-# coding: utf-8
-from __future__ import absolute_import, unicode_literals
-
 from django.db import models
-
-from django_tables2.templatetags.django_tables2 import title
+from django.utils.text import capfirst
 
 from .base import library
 from .linkcolumn import BaseLinkColumn
@@ -11,7 +7,7 @@ from .linkcolumn import BaseLinkColumn
 
 @library.register
 class URLColumn(BaseLinkColumn):
-    '''
+    """
     Renders URL values as hyperlinks.
 
     Arguments:
@@ -22,16 +18,17 @@ class URLColumn(BaseLinkColumn):
     Example::
 
         >>> class CompaniesTable(tables.Table):
-        ...     www = tables.URLColumn()
+        ...     link = tables.URLColumn()
         ...
-        >>> table = CompaniesTable([{'www': 'http://google.com'}])
-        >>> table.rows[0].get_cell('www')
+        >>> table = CompaniesTable([{"link": "http://google.com"}])
+        >>> table.rows[0].get_cell("link")
         '<a href="http://google.com">http://google.com</a>'
-    '''
-    def render(self, record, value):
-        return self.render_link(value, record=record, value=value)
+    """
+
+    def get_url(self, value):
+        return value
 
     @classmethod
     def from_field(cls, field):
         if isinstance(field, models.URLField):
-            return cls(verbose_name=title(field.verbose_name))
+            return cls(verbose_name=capfirst(field.verbose_name))
