@@ -1,27 +1,31 @@
-# coding: utf-8
 from django.core.paginator import EmptyPage, PageNotAnInteger
 
 
-class RequestConfig(object):
+class RequestConfig:
     """
     A configurator that uses request data to setup a table.
 
-    :type  paginate: ``dict`` or ``bool``
-    :param paginate: indicates whether to paginate, and if so, what default
-                     values to use. If the value evaluates to ``False``,
-                     pagination will be disabled. A ``dict`` can be used to
-                     specify default values for the call to
-                     :meth:`.tables.Table.paginate` (e.g. to define a default
-                     ``per_page`` value).
+    A single RequestConfig can be used for multiple tables in one view.
 
-                     A special ``silent`` item can be used to enable automatic
-                     handling of pagination exceptions using the following
-                     algorithm:
+    Arguments:
+        paginate (dict or bool): Indicates whether to paginate, and if so, what
+            default values to use. If the value evaluates to `False`, pagination
+            will be disabled. A `dict` can be used to specify default values for
+            the call to `~.tables.Table.paginate` (e.g. to define a default
+            `per_page` value).
 
-                     - If ``PageNotAnInteger`` is raised, show the first page.
-                     - If ``EmptyPage`` is raised, show the last page.
+            A special *silent* item can be used to enable automatic handling of
+            pagination exceptions using the following logic:
+
+             - If `~django.core.paginator.PageNotAnInteger` is raised, show the first page.
+             - If `~django.core.paginator.EmptyPage` is raised, show the last page.
+
+            For example, to use `~.LazyPaginator`::
+
+                RequestConfig(paginate={"paginator_class": LazyPaginator}).configure(table)
 
     """
+
     def __init__(self, request, paginate=True):
         self.request = request
         self.paginate = paginate
@@ -29,6 +33,9 @@ class RequestConfig(object):
     def configure(self, table):
         """
         Configure a table using information from the request.
+
+        Arguments:
+            table (`~.Table`): table to be configured
         """
         order_by = self.request.GET.getlist(table.prefixed_order_by_field)
         if order_by:
@@ -40,13 +47,13 @@ class RequestConfig(object):
                 kwargs = {}
             # extract some options from the request
             for arg in ("page", "per_page"):
-                name = getattr(table, u"prefixed_%s_field" % arg)
+                name = getattr(table, "prefixed_%s_field" % arg)
                 try:
                     kwargs[arg] = int(self.request.GET[name])
                 except (ValueError, KeyError):
                     pass
 
-            silent = kwargs.pop('silent', True)
+            silent = kwargs.pop("silent", True)
             if not silent:
                 table.paginate(**kwargs)
             else:
@@ -56,3 +63,5 @@ class RequestConfig(object):
                     table.page = table.paginator.page(1)
                 except EmptyPage:
                     table.page = table.paginator.page(table.paginator.num_pages)
+
+        return table
