@@ -1,4 +1,3 @@
-# coding: utf-8
 from django.http import HttpResponse
 from django.shortcuts import get_object_or_404
 
@@ -8,7 +7,7 @@ from .models import Occupation, Person
 def person(request, pk):
     """A really simple view to provide an endpoint for the 'person' URL."""
     person = get_object_or_404(Person, pk=pk)
-    return HttpResponse('Person: %s' % person)
+    return HttpResponse("Person: %s" % person)
 
 
 def occupation(request, pk):
@@ -16,4 +15,4 @@ def occupation(request, pk):
     Another really simple view to provide an endpoint for the 'occupation' URL.
     """
     occupation = get_object_or_404(Occupation, pk=pk)
-    return HttpResponse('Occupation: %s' % occupation)
+    return HttpResponse("Occupation: %s" % occupation)
