@@ -58,40 +58,36 @@ class OrderByTupleTest(TestCase):
 class OrderByTest(TestCase):
     def test_orderby_ascending(self):
         a = OrderBy("a")
-        assert "a" == a
-        assert "a" == a.bare
-        assert "-a" == a.opposite
-        assert True is a.is_ascending
-        assert False is a.is_descending
+        self.assertEqual(a, "a")
+        self.assertEqual(a.bare, "a")
+        self.assertEqual(a.opposite, "-a")
+        self.assertTrue(a.is_ascending)
+        self.assertFalse(a.is_descending)
 
     def test_orderby_descending(self):
         b = OrderBy("-b")
-        assert "-b" == b
-        assert "b" == b.bare
-        assert "b" == b.opposite
-        assert True is b.is_descending
-        assert False is b.is_ascending
+        self.assertEqual(b, "-b")
+        self.assertEqual(b.bare, "b")
+        self.assertEqual(b.opposite, "b")
+        self.assertTrue(b.is_descending)
+        self.assertFalse(b.is_ascending)
 
 
 class AccessorTest(TestCase):
     def test_bare(self):
-        assert "Brad" == Accessor("").resolve("Brad")
-        assert {"Brad"} == Accessor("").resolve({"Brad"})
-        assert {"Brad": "author"} == Accessor("").resolve({"Brad": "author"})
+        self.assertEqual(Accessor("").resolve("Brad"), "Brad")
+        self.assertEqual(Accessor("").resolve({"Brad"}), {"Brad"})
+        self.assertEqual(Accessor("").resolve({"Brad": "author"}), {"Brad": "author"})
 
     def test_index_lookup(self):
-        x = Accessor("0")
-        assert "B" == x.resolve("Brad")
-
-        x = Accessor("1")
-        assert "r" == x.resolve("Brad")
+        self.assertEqual(Accessor("0").resolve("Brad"), "B")
+        self.assertEqual(Accessor("1").resolve("Brad"), "r")
+        self.assertEqual(Accessor("-1").resolve("Brad"), "d")
+        self.assertEqual(Accessor("-2").resolve("Brad"), "a")
 
     def test_calling_methods(self):
-        x = Accessor("2.upper")
-        assert "A" == x.resolve("Brad")
-
-        x = Accessor("2.upper.__len__")
-        assert 1 == x.resolve("Brad")
+        self.assertEqual(Accessor("2.upper").resolve("Brad"), "A")
+        self.assertEqual(Accessor("2.upper.__len__").resolve("Brad"), 1)
 
     def test_honors_alters_data(self):
         class Foo:
@@ -105,16 +101,15 @@ class AccessorTest(TestCase):
         foo = Foo()
         with self.assertRaises(ValueError):
             Accessor("delete").resolve(foo)
-        assert foo.deleted is False
+        self.assertFalse(foo.deleted)
 
     def test_accessor_can_be_quiet(self):
-        foo = {}
-        assert Accessor("bar").resolve(foo, quiet=True) is None
+        self.assertIsNone(Accessor("bar").resolve({}, quiet=True))
 
     def test_penultimate(self):
         context = {"a": {"a": 1, "b": {"c": 2, "d": 4}}}
-        assert Accessor("a.b.c").penultimate(context) == (context["a"]["b"], "c")
-        assert Accessor("a.b.c.d.e").penultimate(context) == (None, "e")
+        self.assertEqual(Accessor("a.b.c").penultimate(context), (context["a"]["b"], "c"))
+        self.assertEqual(Accessor("a.b.c.d.e").penultimate(context), (None, "e"))
 
 
 class AccessorTestModel(models.Model):
@@ -127,25 +122,27 @@ class AccessorTestModel(models.Model):
 class AccessorModelTests(TestCase):
     def test_can_return_field(self):
         context = AccessorTestModel(foo="bar")
-        assert type(Accessor("foo").get_field(context)) == models.CharField
+        self.assertIsInstance(Accessor("foo").get_field(context), models.CharField)
 
     def test_returns_None_when_doesnt_exist(self):
         context = AccessorTestModel(foo="bar")
-        assert Accessor("bar").get_field(context) is None
+        self.assertIsNone(Accessor("bar").get_field(context))
 
     def test_returns_None_if_not_a_model(self):
         context = {"bar": 234}
-        assert Accessor("bar").get_field(context) is None
+        self.assertIsNone(Accessor("bar").get_field(context))
 
 
 class AttributeDictTest(TestCase):
     def test_handles_escaping(self):
-        x = AttributeDict({"x": "\"'x&"})
-        self.assertEqual(x.as_html(), 'x="&quot;&#39;x&amp;"')
+        # django==3.0 replaces &#39; with &#x27;, drop first option if django==2.2 support is removed
+        self.assertIn(
+            AttributeDict({"x": "\"'x&"}).as_html(),
+            ('x="&quot;&#39;x&amp;"', 'x="&quot;&#x27;x&amp;"'),
+        )
 
     def test_omits_None(self):
-        x = AttributeDict({"x": None})
-        self.assertEqual(x.as_html(), "")
+        self.assertEqual(AttributeDict({"x": None}).as_html(), "")
 
     def test_self_wrap(self):
         x = AttributeDict({"x": "y"})
